export declare const autoConverted: {
    true: boolean;
    false: boolean;
    null: null;
    undefined: undefined;
    Infinity: number;
    '-Infinity': number;
};
export declare const converters: {
    /**
     * Default converter - tries to infer if the type is a number, json, or string.
     *
     * @param str a string to parse a value from
     * @returns the value parsed from the string
     */
    auto(str: string): any;
    /**
     * Parse a number from a string
     *
     * @param x
     * @returns
     * @throws {RQLConversionError} when the string cannot be parsed
     */
    number(x: string): number;
    /**
     * Parse a date from a string containing a number representing a UTC timestamp.
     *
     * @param x
     * @returns
     * @throws {RQLConversionError} when the string cannot be parsed
     */
    epoch(x: string): Date;
    /**
     * Parse a date from a string in ISO date format
     *
     * @param x
     * @returns
     */
    isodate(x: string): Date;
    /**
     * Parse a date from a string in YYYY-MM-DDTHH:mm:ss.SSSZ format
     *
     * Milliseconds and "Z" are optional.
     *
     * @param x
     * @returns
     * @throws {RQLConversionError} when the string cannot be parsed
     */
    date(x: string): Date;
    /**
     * Parse a boolean from a string. The string must be 'true' (case insensitive), otherwise it is false.
     *
     * @param x
     * @returns
     */
    boolean(x: string): boolean;
    /**
     * Parse as a string regardless of string contents. Also will URL decode the string.
     *
     * @param str
     * @returns
     */
    string(str: string): string;
    /**
     * Parse a case-insensitive regular expression from a string.
     *
     * @param x
     * @returns
     * @throws {RQLConversionError} when the string cannot be parsed
     */
    ire(x: string): RegExp;
    /**
     * Parse a case-sensitive regular expression from a string
     *
     * @param x
     * @returns
     */
    re(x: string): RegExp;
    /**
     * Parse JSON from a string
     *
     * @param x
     * @returns
     * @throws {RQLConversionError} when the string cannot be parsed
     */
    json(x: string): any;
};
